@@ -8,7 +8,6 @@ from whatap import build
 from whatap.util.date_util import DateUtil
 import threading
 import builtins
-import configparser
 
 __version__ = build.version
 
@@ -49,19 +48,33 @@ LOG_FILE_NAME = 'whatap-hook.log'
 
 isFrappeCommands = "get-frappe-commands" in sys.argv if hasattr(sys, "argv") else False
 
-temporary_config = configparser.ConfigParser()
+def read_ignore_whatap_stdout():
+    ignore_whatap_stdout = 'false'
+    home = os.environ.get('WHATAP_HOME', '.')
+    whatap_config = os.path.join(home, 'whatap.conf')
+    try:
+        with open(whatap_config) as f:
+            for raw in f:
+                line = raw.strip()
+                if not line or line.startswith('#'):
+                    continue
+                if line.startswith('ignore_whatap_stdout'):
+                    parts = line.split('=', 1)
+                    if len(parts) == 2:
+                        ignore_whatap_stdout = parts[1].strip()
+                    break
+        return ignore_whatap_stdout
 
-try:
-    if os.path.exists('whatap.conf'):
-        with open('whatap.conf') as f:
-            file_content = f.read()
-        temporary_file_content = '[dummy_section]\n' + file_content
-        temporary_config.read_string(temporary_file_content)
-        console_option = temporary_config.get('dummy_section', 'ignore_whatap_stdout', fallback='false')
-    else:
-        console_option = 'false'
-except Exception as e:
-    print('WHATAP : WHATAP.CONF READ ERROR')
+    except FileNotFoundError:
+        return ignore_whatap_stdout
+
+    except Exception as e:
+        print(f'WHATAP: config parse error ({e!r})')
+        return ignore_whatap_stdout
+
+
+
+ignore_whatap_stdout = read_ignore_whatap_stdout()
 
 
 
@@ -70,7 +83,7 @@ original_print = builtins.print
 def print_option(func):
     def wrapper(*args, **kwargs):
 
-        if(console_option == 'false'):
+        if(ignore_whatap_stdout == 'false'):
             result = func(*args, **kwargs)
         else:
             result = None
