@@ -96,7 +96,8 @@ def start_interceptor(ctx):
              ctx.userAgentString,
              ctx.referer,
              ctx.userid,
-             ctx.isStaticContents
+             ctx.isStaticContents,
+             ctx.http_method
              ]
     # print("start_interceptor txid:", ctx.id)
     async_sender.send_packet(PacketTypeEnum.TX_START, ctx, datas)
@@ -121,7 +122,7 @@ def end_interceptor(thread_id=None, ctx=None):
     ctx.start_time = start_time
 
     datas = [ctx.host, ctx.service_name, ctx.mtid, ctx.mdepth, ctx.mcaller_txid,
-             ctx.mcaller_pcode, ctx.mcaller_spec, str(ctx.mcaller_url_hash), ctx.mcaller_poid]
+             ctx.mcaller_pcode, ctx.mcaller_spec, str(ctx.mcaller_url_hash), ctx.mcaller_poid,ctx.status]
     ctx.elapsed = DateUtil.nowSystem() - start_time
 
     async_sender.send_packet(PacketTypeEnum.TX_END, ctx, datas)
@@ -149,7 +150,7 @@ def interceptor(rn_environ, *args, **kwargs):
     ctx = TraceContext()
     ctx.host = environ.get('HTTP_HOST', '').split(':')[0]
     ctx.service_name = parseServiceName(environ)
-
+    ctx.http_method = environ.get('REQUEST_METHOD', '')
     ctx.remoteIp = userid_util.getRemoteAddr(args)
 
     ctx.userAgentString = environ.get('HTTP_USER_AGENT', '')
@@ -206,8 +207,10 @@ def interceptor(rn_environ, *args, **kwargs):
 
         if getattr(callback, 'status_code', None):
             status_code = callback.status_code
-            errors = [callback.__class__.__name__, callback.reason_phrase]
-            interceptor_error(status_code, errors, ctx=ctx)
+
+            if (status_code >= 400):
+                errors = [callback.__class__.__name__, callback.reason_phrase]
+                interceptor_error(status_code, errors, ctx=ctx)
 
         if conf.profile_http_header_enabled:
             keys = []
@@ -234,8 +237,8 @@ def interceptor_error(status_code, errors, ctx=None):
         ctx = TraceContextManager.getLocalContext()
     if not ctx:
         return
-    ctx.status = int(status_code / 100)
-    if ctx.status >= 4 and not ctx.error:
+    ctx.status = status_code
+    if status_code >= 400 and not ctx.error:
         ctx.error = 1
 
         error = ''
