@@ -11,8 +11,8 @@ def instrument_oracle_client(module):
         @trace_handler(fn)
         def trace(*args, **kwargs):
             global db_info
-            db_info = {'type': 'oracle'} | kwargs
-
+            db_info = {'type': 'oracle'}
+            db_info.update(kwargs)
             callback = interceptor_db_con(fn, db_info, *args, **kwargs)
             return callback
 
