@@ -38,6 +38,9 @@ DEFINITION = {
         ('sqlalchemy.engine.create', 'instrument_sqlalchemy_engine_basic'),
         ('sqlalchemy.engine', 'instrument_sqlalchemy_engine_basic'),
     ],
+    'application_starlette' : [
+        ('starlette.websockets' , 'instrument_starlette_websocket'),
+    ],
     'application_wsgi': [
         ('', ''),
     ],
